@@ -4,11 +4,13 @@ package Module::Build::Pluggable::PDL;
 
 use strict;
 use warnings;
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 use parent qw(Module::Build::Pluggable::Base);
 
 use PDL::Core::Dev;
 use List::MoreUtils qw(first_index);
+use Config;
+use Pod::Perldoc;
 
 sub HOOK_build {
     my ($self) = @_;
@@ -75,31 +77,14 @@ sub process_pd_files {
     for my $file (@$files) {
         my ( $build_prefix, $prefix, $mod_name ) = $self->_filename2info($file);
 
-        # see sub run_perl_command (yet undocumented)
-        # PDL::PP's import argument are, in order:
-        # Module name -> for example, PDL::Graphics::PLplot
-        # Package name -> used in package line of the .pm file; for our purposes,
-        #     this is identical to Module name.
-        # Prefix -> the extensionless file name, PDL/Graphics/PLplot
-        #    .pm and .xs extensions will be added to this when the files are
-        #    produced, so this should include a lib/ prefix
-        # Callpack -> an optional argument used for the XS PACKAGE keyword;
-        #    if left blank, it will be identical to the module name
-        my $PDL_arg = "-MPDL::PP qw[$mod_name $mod_name $build_prefix]";
-
-        # Both $self->up_to_date and $self->run_perl_command are undocumented
-        # so they could change in the future:
-        my $up_to_date = $builder->up_to_date( $file,
-            [ "$build_prefix.pm", "$build_prefix.xs" ] );
-        if ( $builder->{FORCE_PDL_PP_BUILD} or not $up_to_date ) {
-            $builder->run_perl_command( [ $PDL_arg, $file ] );
-        }
+        $self->_convert_to_pm( $file, $build_prefix, $prefix, $mod_name );
 
         $self->_add_to_provides( {
             mod_name => $mod_name,
             file     => $file,
             version  => $builder->dist_version
         } );
+
         $builder->add_to_cleanup( "$build_prefix.pm", "$build_prefix.xs" );
 
         # Add the newly created .pm and .xs files to the list of such files?
@@ -109,6 +94,32 @@ sub process_pd_files {
     }
 }
 
+sub _convert_to_pm {
+    my ( $self, $file, $build_prefix, $prefix, $mod_name ) = @_;
+    my $builder = $self->builder;
+
+    # see sub run_perl_command (yet undocumented)
+    # PDL::PP's import argument are, in order:
+    # Module name -> for example, PDL::Graphics::PLplot
+    # Package name -> used in package line of the .pm file; for our purposes,
+    #     this is identical to Module name.
+    # Prefix -> the extensionless file name, PDL/Graphics/PLplot
+    #    .pm and .xs extensions will be added to this when the files are
+    #    produced, so this should include a lib/ prefix
+    # Callpack -> an optional argument used for the XS PACKAGE keyword;
+    #    if left blank, it will be identical to the module name
+    my $PDL_arg = "-MPDL::PP qw[$mod_name $mod_name $build_prefix]";
+
+    # Both $self->up_to_date and $self->run_perl_command are undocumented
+    # so they could change in the future:
+    my $up_to_date =
+      $builder->up_to_date( $file, [ "$build_prefix.pm", "$build_prefix.xs" ] );
+
+    if ( $builder->{FORCE_PDL_PP_BUILD} or not $up_to_date ) {
+        $builder->run_perl_command( [ $PDL_arg, $file ] );
+    }
+}
+
 sub _add_to_provides {
     my ( $self, $info ) = @_;
 
@@ -148,14 +159,19 @@ sub HOOK_distdir {
         ( my $prefix       = $build_prefix ) =~ s{/?lib/}{};
         ( my $package      = $build_prefix ) =~ s{/}{::}g;
 
+        # Process .pd into a .pm file with embedded POD
         # perl -MPDL::PP=PDL::Opt::QP,PDL::Opt::QP,lib/PDL/Opt/QP lib/PDL/Opt/QP.pd
+        my $cmd = sprintf "%s -MPDL::PP=%s,%s,%s %s",
+          $Config{perlpath}, $package, $package, $build_prefix, $file;
+        $self->do_system($cmd) or die "Error running PDL::PP : $@";
+
+        # Process .pm into .pod using perldoc as an object
         # && perldoc -u lib/PDL/Opt/QP.pm > lib/PDL/Opt/QP.pod
-        my $cmd =
-          sprintf "perl -MPDL::PP=%s,%s,%s %s && perldoc -u %s.pm > %s.pod",
-          $package, $package, $build_prefix, $file, $build_prefix,
-          $build_prefix;
+        my $poddoc =
+          Pod::Perldoc->new(
+            args => ['-u', '-d', "$build_prefix.pod", "$build_prefix.pm"] );
+        $poddoc->process();
 
-        $self->do_system($cmd);
         $self->add_to_cleanup("$build_prefix.pod");
     }
 
@@ -174,7 +190,7 @@ Module::Build::Pluggable::PDL - Plugin to Module::Build to build PDL projets
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
